# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing interaction of local and foreign links.

flex container

flex container

## Index

### Terms defined by this specification

- flex container, in §Unnumbered section

https://drafts.csswg.org/css-flexbox-1/#flex-container Referenced in:

- Unnamed section

### Terms defined by reference

- [css-flexbox-1] defines the following terms:
  - flex container

## References

### Normative References

[CSS-FLEXBOX-1]
  Tab Atkins Jr.; et al. CSS Flexible Box Layout Module Level 1. 19 November 2018. CR. URL: https://www.w3.org/TR/css-flexbox-1/